function obj=randi(varargin)
% FUNCTION fc_amat.random.randi
% -- fc_amat.random.randi(Imax,N,m,n)
% -- fc_amat.random.randi(Imax,[N,m,n])
%      Returns a N-by-m-by-n amat object whose elements are drawn from the 
%      discrete uniform distribution on 1:Imax.
%
% -- fc_amat.random.randi(Imax,N,d)
%      Returns a N-by-d-by-d amat object whose elements are drawn from the 
%      discrete uniform distribution on 1:Imax.
%
% -- fc_amat.random.randi([Imin,Imax],...)
%      Elements are drawn from the discrete uniform distribution on Imin:Imax.
%
% -- fc_amat.random.randi(...,classname)
%      Optional classname argument can be used to return an amat object of the 
%      specified class. The default is "double". See Matlab randi function.
%
%      See also: fc_amat.random.rand, fc_amat.random.randi,
%                fc_amat.zeros, fc_amat.ones, fc_amat.eye,
%                class amat
%
  classname='double';
  assert( ismember(nargin,[2,3,4,5]) )
  n=nargin;
  if ischar(varargin{end})
    classname=varargin{end};
    n=n-1;
  end
  Imax=varargin{1};
  switch n
    case 2 % varargin={Imax,[N,m,n]} or varargin={Imax,[N,m,n],classname}
      S=varargin{2}; assert(length(S)==3,'2nd argument must be an [N,m,n] array')
      N=S(1);m=S(2);n=S(3);
    case 3 % varargin={Imax,N,m} or % varargin={Imax,N,m,classname}
        N=varargin{2};m=varargin{3};n=m;
    case 4  % varargin={Imax,N,m,n} or % varargin={Imax,N,m,n,classname}
      N=varargin{2};
      m=varargin{3};
      n=varargin{4};
  end
  obj=amat(randi(Imax,N,m,n,classname));
end
